<?php

defined('COT_CODE') or die('Wrong URL');

define('WIDGET_LOCATIONS', 'header,footer,index,page,list');
define('WIDGET_TYPES', 'plain,html');

/**
 * Build widget output HTML
 *
 * @param string $contents
 * @param string $type
 * @return string
 */
function widgets_build_output($contents, $type)
{
	switch($type)
	{
		case 'plain':
			return htmlspecialchars($contents);

		case 'html':
			return $contents;
	}
	die('Unknown widget type');
}

/**
 * Get widget configuration
 *
 * @global object $cache
 * @global string $db_x
 * @param string $location Widget location
 * @return array Multidimensional array containing database records for the widgets
 */
function widgets_get_config($location='')
{
	global $cache, $db, $db_x;

	$is_valid_location = in_array($location, explode(',', WIDGET_LOCATIONS));

	if($cache && $is_valid_location && $cache->db->exists('widgets_'.$location, 'widgets'))
	{
		$cachedata = $cache->db->get('widgets_'.$location, 'widgets');
		if(is_array($cachedata)) return $cachedata;
	}

	$sqlcond = array(' WHERE 1');
	if($is_valid_location)
	{
		$sqlcond[] = "widget_location = '$location'";
	}

	$sql = $db->query("
		SELECT * FROM {$db_x}widgets" . implode(' AND ', $sqlcond) . "
		ORDER BY widget_location, widget_code
	");
	$res = $sql->fetchAll($fetch_style=PDO::FETCH_ASSOC);
	$cache && $is_valid_location && $cache->db->store('widgets_'.$location, $res, 'widgets');
	return $res;
}

/**
 * Build tags for each widget
 *
 * @param string $location Widget location
 * @return array Tags to be passed to $t->assign()
 */
function widgets_get_tags($location)
{
	$tags = array();
	$widgets = widgets_get_config($location);
	foreach($widgets as $widget)
	{
		$output = widgets_build_output($widget['widget_contents'], $widget['widget_type']);
		$tags['WIDGET_' . strtoupper($widget['widget_code'])] = $output;
	}
	return $tags;
}

/**
 * Add a new widget
 *
 * @global object $db
 * @global string $db_x
 * @return mixed
 */
function widgets_admin_add($code, $location, $type, $contents)
{
	cot_block(cot_auth('plug', 'widgets', 'A'));

	global $cache, $db, $db_x;
	
	if(!$code)
	{
		cot_message('error_add_code', 'error');
		return false;
	}
	if(!in_array($location, explode(',', WIDGET_LOCATIONS)))
	{
		cot_message('error_add_location', 'error');
		return false;
	}
	if(!in_array($type, explode(',', WIDGET_TYPES)))
	{
		cot_message('error_add_type', 'error');
		return false;
	}
	if(!$contents)
	{
		cot_message('error_add_contents', 'error');
		return false;
	}

	$cache && $cache->db->remove('widgets_'.$location, 'widgets');

	$params = array($code, $location, $type, $contents);
	return $db->query("INSERT INTO {$db_x}widgets (
		widget_code, widget_location, widget_type, widget_contents
	) VALUES (
		'{$db->prep(strtolower($code))}', '{$db->prep(strtolower($location))}', '{$db->prep(strtolower($type))}', '{$db->prep($contents)}'
	)");
}

/**
 * Remove a widget
 *
 * @global object $db
 * @global string $db_x
 * @return mixed
 */
function widgets_admin_remove($code, $location)
{
	cot_block(cot_auth('plug', 'widgets', 'A'));
	
	global $cache, $db, $db_x;

	if(!$code)
	{
		cot_message('error_remove_code', 'error');
		return false;
	}
	if(!in_array($location, explode(',', WIDGET_LOCATIONS)))
	{
		cot_message('error_remove_location', 'error');
		return false;
	}
	
	$cache && $cache->db->remove('widgets_'.$location, 'widgets');
	
	$where = 'widget_code = ? AND widget_location = ?';
	$params = array($code, $location);
	return $db->delete($db_x.'widgets', $where, $params);
}

?>